# Security Policy

## Supported Versions

:white_check_mark: = Supported   :lock: = Security updates   :x: = Not supported

| Version   | Supported          |
| --------- | ------------------ |
| 2.8.x     | :white_check_mark: |
| 2.7.x     | :white_check_mark: |
| > 2.x.x   | :lock:             |
| 1.x.x     | :x:                |

> All security fixes will be added the next release. Unless the threat is major the fix will be released with in the normal release
> schedule.

## Reporting a Vulnerability

We take security very seriously with thousands of users using our library we need the communities help to spot security
vulnerabilities.

If you think you have found a vulnerability or have any concerns about our security please feel free to reach out to us using
the details below.

 - Email: security@fomantic-ui.com or contact@fomantic-ui.com
 - Twitter: [@fomanticui](https://twitter.com/fomanticui)
 - Discord: [https://discord.gg/YChxjJ3](https://discord.gg/YChxjJ3)
